@@ -5,13 +5,13 @@
 #   Name:
 #       GD::Graph::area.pm
 #
-# $Id: area.pm,v 1.13 2002/06/09 03:15:15 mgjv Exp $
+# $Id: area.pm,v 1.16 2005/12/14 04:09:06 ben Exp $
 #
 #==========================================================================
 
 package GD::Graph::area;
  
-$GD::Graph::area::VERSION = '$Revision: 1.13 $' =~ /\s([\d.]+)/;
+($GD::Graph::area::VERSION) = '$Revision: 1.16 $' =~ /\s([\d.]+)/;
 
 use strict;
 
@@ -50,12 +50,14 @@ sub draw_data_set
 
         my ($x, $y) = $self->val_to_pixel($i + 1, $value, $ds);
         $poly->addPt($x, $y);
-        # XXX Wish I could remember why I did this @bottom thing again,
-        # instead of just using one straight connector
+	# Need to keep track of this stuff for hotspots, and because
+	# it's the only reliable way of closing the polygon, without
+	# making odd assumptions.
         push @bottom, [$x, $bottom];
 
         # Hotspot stuff
-        # XXX needs fixing
+        # XXX needs fixing. Not used at the moment.
+	next unless defined $self->{_hotspots}->[$ds]->[$i];
         if ($i == 0)
         {
             $self->{_hotspots}->[$ds]->[$i] = ["poly", 
@@ -94,7 +96,8 @@ sub draw_data_set
         for (my $i = 1; $i < @values - 1; $i++)
         {
             my $value = $values[$i];
-            next unless defined $value;
+	    ## XXX Why don't I need this line?
+            ##next unless defined $value;
 
             my ($x, $y) = $poly->getPt($i);
             my $bottom = $bottom[$i]->[1];
