@@ -1,7 +1,7 @@
 use GD::Graph::lines;
 require 'save.pl';
 
-print STDERR "Processing sample 5-2\n";
+print STDERR "Processing sample52\n";
 
 @data = ( 
     [ qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec) ],
@@ -29,6 +29,8 @@ $my_graph->set(
 
 	x_label_skip => 3,
 	x_tick_offset => 2,
+
+	transparent => 0,
 );
 
 $my_graph->set_legend("Us", "Them", "Others");
